#!/bin/bash
#

usage()
{
   echo "USAGE: `basename ${0}` <product_dir> [tar]"
}
# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=""
extraqual=""
maketar=${2}


if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi


# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=epics_css_alarm_server
origpkgver=v3_3_10a
pkgver=${origpkgver}
ssibuildshims_version=v1_00_00
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=epics_css_alarm_server-${pkgdotver}
pkgtarfile=${pkgtarname}-linux.gtk.x86_64.tar.bz2


apply_these_patches=(v3.3.10a)


get_this_dir

get_ssibuildshims

source define_basics NO_QUAL --


if [ "${maketar}" = "tar" ] && [ -f ${pkgdir}/run_alarmserver ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
   exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi

set -x

cd ${blddir}
tar jxf ${tardir}/${pkgtarfile}  >/dev/null 2>&1 || die "unable to unwind ${pkgtarfile}"

# patch
patchdir=${thisdir}/patch

cd ${blddir}/

for this_patch in ${apply_these_patches[*]}; do
  patchfile=${patchdir}/${package}-${this_patch}.patch
  patch --verbose -p1 -i ${patchfile} || ssi_die "ERROR: patch failed; file $(basename ${patchfile})"
done

cd ${pkgdir}
chmod a+x ${blddir}/run_alarmserver  || die "unable to chmod a+x ${blddir}/run_alarmserver"
chmod a+x ${blddir}/run_alarmconfigtool  || die "unable to chmod a+x ${blddir}/run_alarmconfigtool"

cp -r ${blddir}/* ${pkgdir}/ || die "unable to copy cs-studio files"

set +x

${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL || die "declare_product failed"

#-------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir}:${PRODUCTS} || die "setup failed"

# this must be last 
if [ "${maketar}" = "tar" ] && [ -f ${pkgdir}/run_alarmserver ] && [ -f ${pkgdir}/run_alarmconfigtool ] 
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
fi

exit 0